eukalypse_brew
=============

.. image:: https://secure.travis-ci.org/kinkerl/eukalypse_brew.png
    :alt: Travis CI Build Status


website sanity checks from the users point of view

Resources
---------

* `Documentation <http://eukalypse_brew.readthedocs.org/en/latest/>`_
* `Continuous Integration <https://travis-ci.org/kinkerl/eukalypse_brew>`_
